function [T, N, U] = solve_constant(t0, tF, a, K, N0, u_const)
% Function to solve N' = aN(1-N/K) - u(t)*N for constant control u(t)
% Note: logistic growth and log-kill hypothesis
% Arguments:
    % t0:  initial time
    % tF:  final time
    % a:  growth rate
    % K:  carrying capacity
    % N0:  initial tumor size
    % u_const:  constant value of u(t) (u(t) = u_const)
% Returns:
    % T:  vector of times solution is evalued on
    % N:  corresponding population size
    % U:  vector of applied treatment

[T,N] = ode45(@(t,N)rhs(t,N,a,K,u_const), [t0 tF], N0);
U = u_const*ones(length(T),1);  % Return vector of constant u as well

end

function dNdt = rhs(t, N, a, K, u)
% Auxillary vector field for logisitc growth
% Used in above function

dNdt = a*N.*(1-N/K) - u*N;

end

